@@ -482,8 +482,7 @@ end
         mktemp() do connection_file, io
             # Write the connection file
             jupyter_client_lib.connect.write_connection_file(; fname=connection_file, profile_kwargs...)
-
-            cmd = `$julia --startup-file=no --project=$(Base.active_project()) -e 'import IJulia; IJulia.run_kernel()' $(connection_file)`
+            cmd = `$(Base.julia_cmd()) --project=$(Base.active_project()) -e 'import IJulia; IJulia.run_kernel()' $(connection_file)`
             kernel_proc = run(pipeline(cmd; stdout, stderr); wait=false)
             try
                 jupyter_client(profile) do client
